import { FC, PropsWithChildren, useMemo } from "react";

import { ThemeProvider, Theme } from '@mui/material/styles';
import createCache from "@emotion/cache";
import { CacheProvider } from "@emotion/react";

type NuskinThemeProviderProps = {
    isSSR?: boolean;
    cacheKey?: string;
    appTheme?: Theme;
};

const getCacheKey = (key: string) => {
    return createCache({ key });
};

const NuskinThemeProvider: FC<PropsWithChildren<NuskinThemeProviderProps>> = (props) => {
    const {
        isSSR = false,
        children,
        cacheKey = "nuskin-default",
        appTheme
    } = props;

    const cache = useMemo(() => getCacheKey(cacheKey), [cacheKey]);

    if (isSSR) {
        return (
            <CacheProvider value={cache}>
                <ThemeProvider theme={appTheme || {}}>
                    {children}
                </ThemeProvider>
            </CacheProvider>
        )
    }
    return (
        <ThemeProvider theme={appTheme || {}}>
            {children}
        </ThemeProvider>
    );
};

export default NuskinThemeProvider;