import { createTheme } from "@mui/material";

import { palette as defaultPalette } from "../themes/genome-foundation/";
export * from "./button-utils";

type Palette = {
    main: string;
    contrastText?: string;
    buttonState?: {
        hovered?: string;
        disabled?: string;
        pressed?: string;
        focused?: string;
        disabledText?: string;
    },
    darkMode?: {
        main?: string;
        contrastText?: string;
        buttonState?: {
            hovered?: string;
            hoveredText?: string;
            pressed?: string;
            pressedText?: string;
            focused?: string;
            disabled?: string;
        }
    }
};

export type Colors = {
    primary: Palette;
    secondary: Palette;
    accentColorA: Palette;
    accentColorB: Palette;
    accentColorC: Palette;
    success: Palette;
    error: Palette;
    warning: Palette;
    info: Palette
}


export const generatePalette = (colors: Colors, prefersDarkMode = false) => {
    const colorKeys = Object.keys(colors) as any[];
    const paletteColors = colorKeys.reduce((result, paletteName: keyof Colors) => {
        if (prefersDarkMode) {
            const colorObject = colors[paletteName];
            const darkMode = colorObject?.darkMode;
            if (darkMode) {
                result[paletteName] = darkMode;
            }
        }
        return result;
    }, {});
    return paletteColors;
};

export const createNuskinTheme = (palette: Colors = defaultPalette, prefersDarkMode?: boolean) => {
    const muiTheme = createTheme({ palette })
    return {
        ...muiTheme,
        palette: {
            ...muiTheme.palette,
            ...generatePalette(palette, prefersDarkMode),
        }
    };
}